## Typing stubs for PyMySQL

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`PyMySQL`](https://github.com/PyMySQL/PyMySQL) package. It can be used by type checkers
to check code that uses `PyMySQL`. This version of
`types-PyMySQL` aims to provide accurate annotations for
`PyMySQL==1.1.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/PyMySQL`](https://github.com/python/typeshed/tree/main/stubs/PyMySQL)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.20.0
* [pyright](https://github.com/microsoft/pyright) 1.1.408

It was generated from typeshed commit
[`563213272e5db2a858e37bdf6938b0c8742ec192`](https://github.com/python/typeshed/commit/563213272e5db2a858e37bdf6938b0c8742ec192).